# -*- coding: utf-8 -*-

"""
LUCA/PSO toolkit
=========================================
This is ...

"""

__author__ = """Olaf David"""
__email__ = "odavid@colostate.edu"
__version__ = "1.0"

from .pso import global_best

__all__ = ["global_best"]